"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isObjectEmpty = exports.insertSorted = exports.parseEvent = void 0;
const Constants_1 = require("./Constants");
/**
 * Splits the given event string into namespace and event name parts.
 * @param event - The event string to parse.
 * @returns A tuple containing the namespace and event name.
 */
const parseEvent = (event) => {
    const parts = event.split(Constants_1.separator);
    const namespace = parts.length > 1 ? parts[0] : '';
    const eventName = parts[parts.length - 1];
    return [namespace, eventName];
};
exports.parseEvent = parseEvent;
/**
 * Inserts a listener object into a sorted array based on priority.
 * @param listeners - The array of listener objects to insert into.
 * @param listenerObject - The listener object to be inserted, containing the listener function and its priority.
 */
const insertSorted = (listeners, listenerObject) => {
    const index = listeners.findIndex(l => listenerObject.priority > l.priority);
    if (index === -1) {
        listeners.push(listenerObject);
    }
    else {
        listeners.splice(index, 0, listenerObject);
    }
};
exports.insertSorted = insertSorted;
/**
 * Checks if the provided object is empty (has no own enumerable properties).
 * @param obj - The object to check for emptiness.
 * @returns `true` if the object is empty; otherwise, `false`.
 */
const isObjectEmpty = (obj) => {
    return Object.keys(obj).length === 0;
};
exports.isObjectEmpty = isObjectEmpty;
